package top.daxian1218.dust.license.device;

import com.alibaba.fastjson.JSONObject;
import org.apache.commons.lang3.StringUtils;
import top.daxian1218.dust.commons.exception.DustSystemException;
import top.daxian1218.dust.license.LicenseConfig;
import top.daxian1218.dust.license.util.RSAUtil;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

public class DeviceCollector {
    private List<IDevice> deviceList = new ArrayList<>();

    public DeviceCollector() {
        deviceList.add(new LinuxDevice());
        deviceList.add(new WindowsDevice());
    }

    public void register(IDevice device) {
        deviceList.add(device);
    }

    public String getDeviceFingerPrint() {
        if (StringUtils.isEmpty(LicenseConfig.INSTANCE.getPublicKey())) {
            throw new DustSystemException("授权设备公钥未设置", "1001");
        }


        String osName = System.getProperty("os.name").toLowerCase();

        Optional<IDevice> device = deviceList.stream().filter(d -> d.Support(osName)).findFirst();
        if (!device.isPresent()) {
            throw new DustSystemException("设置指纹获取失败, 程序终止");
        }

        IDevice curDevice = device.get();
        List<String> fingerPrint = new ArrayList<>();
        if (LicenseConfig.INSTANCE.isCpuCheck()) {
            fingerPrint.add("cpu=" + curDevice.GetCpuSN());
        }

        if (LicenseConfig.INSTANCE.isHostNameCheck()) {
            fingerPrint.add("hostname=" +curDevice.GetHostName());
        }

        if (LicenseConfig.INSTANCE.isMacCheck()) {
            fingerPrint.add("mac=" +curDevice.GetMacAddress());
        }

        if (LicenseConfig.INSTANCE.isMainboardCheck()) {
            fingerPrint.add("mainboard=" +curDevice.GetMainBoardSN());
        }

        return  String.join(",", fingerPrint.toArray(new String[0]));
    }

    public String getDeviceFingerPrintOfRSA() {
        return RSAUtil.encrypt(getDeviceFingerPrint(), LicenseConfig.INSTANCE.getPublicKey());
    }
}
