package top.daxian1218.dust.license.util;

import org.apache.commons.lang3.StringUtils;
import top.daxian1218.dust.commons.log.LoggerHelper;
import top.daxian1218.dust.commons.util.TypeUtil;

import java.io.*;
import java.nio.charset.StandardCharsets;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

public class LicenseFileUtil {
    public static String hash(InputStream stream) {
        try {
            MessageDigest md = MessageDigest.getInstance("SHA-1");
            int len = 0;
            byte[] bytes = new byte[1024];
            while ((len = stream.read(bytes)) > 0) {
                md.update(bytes, 0, len);
            }

            byte[] hashBytes = md.digest();

            return TypeUtil.toString(hashBytes);

        } catch (NoSuchAlgorithmException | IOException e) {
            LoggerHelper.debug(e);
        }

        return StringUtils.EMPTY;
    }

    public static String readAll(File file) throws IOException {
        StringBuffer sb = new StringBuffer();
        FileInputStream stream = new FileInputStream(file);
        BufferedReader br = new BufferedReader(new InputStreamReader(stream, StandardCharsets.UTF_8));
        String line = null;
        while ((line = br.readLine()) != null) {
            sb.append(line.trim());
        }

        br.close();
        return sb.toString();
    }

    public static String writeAll(File file, String body) throws IOException {
        StringBuffer sb = new StringBuffer();
        FileOutputStream stream = new FileOutputStream(file);
        BufferedWriter br = new BufferedWriter(new OutputStreamWriter(stream, StandardCharsets.UTF_8));
        br.write(body);
        br.flush();
        br.close();
        return sb.toString();
    }

    public static boolean deleteDirectory(File dir) {
        if ((dir == null) || !dir.isDirectory()) {
            throw new IllegalArgumentException("Argument " + dir +
                    " is not a directory. ");
        }

        File[] entries = dir.listFiles();
        assert entries != null;

        for (File entry : entries) {
            if (entry.isDirectory()) {
                if (!deleteDirectory(entry)) {
                    return false;
                }
            } else {
                if (!entry.delete()) {
                    return false;
                }
            }
        }

        if (!dir.delete()) {
            return false;
        }
        return true;
    }
}
